==> physx-jni-0.4.0-sources.jar: physx/physics/PxContactPairHeader.java <==
package physx.physics;

import physx.NativeObject;

public class PxContactPairHeader extends NativeObject {

    protected PxContactPairHeader() { }

    public static PxContactPairHeader wrapPointer(long address) {
        return new PxContactPairHeader(address);
    }
    
    protected PxContactPairHeader(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @param index Array index
     * @return WebIDL type: {@link PxRigidActor}
     */
    public PxRigidActor getActors(int index) {
        return PxRigidActor.wrapPointer(_getActors(address, index));
    }
    private static native long _getActors(long address, int index);

    /**
     * @param index Array index
     * @param value WebIDL type: {@link PxRigidActor}
     */
    public void setActors(int index, PxRigidActor value) {
        _setActors(address, index, value.getAddress());
    }
    private static native void _setActors(long address, int index, long value);

    /**
     * @return WebIDL type: {@link PxContactPairHeaderFlags} [Value]
     */
    public PxContactPairHeaderFlags getFlags() {
        return PxContactPairHeaderFlags.wrapPointer(_getFlags(address));
    }
    private static native long _getFlags(long address);

    /**
     * @param value WebIDL type: {@link PxContactPairHeaderFlags} [Value]
     */
    public void setFlags(PxContactPairHeaderFlags value) {
        _setFlags(address, value.getAddress());
    }
    private static native void _setFlags(long address, long value);

    /**
     * @return WebIDL type: {@link PxContactPair}
     */
    public PxContactPair getPairs() {
        return PxContactPair.wrapPointer(_getPairs(address));
    }
    private static native long _getPairs(long address);

    /**
     * @param value WebIDL type: {@link PxContactPair}
     */
    public void setPairs(PxContactPair value) {
        _setPairs(address, value.getAddress());
    }
    private static native void _setPairs(long address, long value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbPairs() {
        return _getNbPairs(address);
    }
    private static native int _getNbPairs(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setNbPairs(int value) {
        _setNbPairs(address, value);
    }
    private static native void _setNbPairs(long address, int value);

}

==> physx-jni-0.4.1-sources.jar: physx/physics/PxContactPairHeader.java <==
package physx.physics;

import physx.NativeObject;

public class PxContactPairHeader extends NativeObject {

    protected PxContactPairHeader() { }

    public static PxContactPairHeader wrapPointer(long address) {
        return address != 0L ? new PxContactPairHeader(address) : null;
    }
    
    protected PxContactPairHeader(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @param index Array index
     * @return WebIDL type: {@link PxRigidActor}
     */
    public PxRigidActor getActors(int index) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxRigidActor.wrapPointer(_getActors(address, index));
    }
    private static native long _getActors(long address, int index);

    /**
     * @param index Array index
     * @param value WebIDL type: {@link PxRigidActor}
     */
    public void setActors(int index, PxRigidActor value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setActors(address, index, value.getAddress());
    }
    private static native void _setActors(long address, int index, long value);

    /**
     * @return WebIDL type: {@link PxContactPairHeaderFlags} [Value]
     */
    public PxContactPairHeaderFlags getFlags() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxContactPairHeaderFlags.wrapPointer(_getFlags(address));
    }
    private static native long _getFlags(long address);

    /**
     * @param value WebIDL type: {@link PxContactPairHeaderFlags} [Value]
     */
    public void setFlags(PxContactPairHeaderFlags value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setFlags(address, value.getAddress());
    }
    private static native void _setFlags(long address, long value);

    /**
     * @return WebIDL type: {@link PxContactPair} [Const]
     */
    public PxContactPair getPairs() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxContactPair.wrapPointer(_getPairs(address));
    }
    private static native long _getPairs(long address);

    /**
     * @param value WebIDL type: {@link PxContactPair} [Const]
     */
    public void setPairs(PxContactPair value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setPairs(address, value.getAddress());
    }
    private static native void _setPairs(long address, long value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbPairs() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getNbPairs(address);
    }
    private static native int _getNbPairs(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setNbPairs(int value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setNbPairs(address, value);
    }
    private static native void _setNbPairs(long address, int value);

}
